__version__ = '0.9.40'
Version = __version__ # for backware compatibility

from vim import Vim, Sms
